/*******************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain
 * this notice you can do whatever you want with this stuff. If we meet some
 * day, and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 *******************************************************************************
 * 
 * File: app_eemem.h
 * 
 * Version: 1.0
 * Created: 16.07.2023
 * 
 * Author: Mario Hellmich <mario.hellmich@web.de>
 * Project: RF Synthesizer MK III
 * 
 * Summary: This header file provides prototypes and definitions for 
 * app_eemem.c.
 * 
 * *****************************************************************************/

#ifndef APP_EEMEM_H
#define	APP_EEMEM_H


/*Section: Includes ************************************************************/

#include "definitions.h"
#include "app_instr_state.h"
#include "app_system_operation.h"
#include <string.h>


#ifdef	__cplusplus
extern "C" {
#endif


/* Type definitions: ***********************************************************/

#define N_LVL_CORR_POINTS           ((FREQ_CORR_TRANS - FREQ_MIN) / FREQ_CORR_SPACING_LO) + ((FREQ_MAX - FREQ_CORR_TRANS) / FREQ_CORR_SPACING_HI) + 2       // Total number of level calibration frequency points

typedef struct {
    float sig_path[N_LVL_CORR_POINTS];      // Overall correction of signal path (with attenuator set to 0 dB), unit: dB
    float step_3db[N_LVL_CORR_POINTS];      // Correction of the 3 dB attenuator step, unit: dB
    float step_6db[N_LVL_CORR_POINTS];      // Correction of the 6 dB attenuator step, unit: dB
    float step_12db[N_LVL_CORR_POINTS];     // Correction of the 12 dB attenuator step, unit: dB
    float step_24db[N_LVL_CORR_POINTS];     // Correction of the 24 dB attenuator step, unit: dB
} Lvl_Corr_t;


typedef struct {
    Lvl_Corr_t lvlcorr;                     // EEPROM level correction data, units as in Lvl_Corr_t
    float slopecorr;                        // EEPROM detector slope correction value, unit: in mV/dB
    double frqcorr;                         // EEPROM frequency correction value for internal 10 MHz reference, unit: Hz
    char calstring[STRARG_LEN + 1];         // Calibration string
} Calibration_Data_t;


/* Variables: ******************************************************************/

extern Calibration_Data_t caldata_ram;


/*Section: Function prototypes: ************************************************/

extern void load_cal_data(void);
extern void save_cal_data(void);
extern bool mem_recall(unsigned int mem);
extern bool mem_save(unsigned int mem);
extern void eeprom_erase(void);


#ifdef	__cplusplus
}
#endif

#endif	/* APP_EEMEM_H */


/*******************************************************************************
 End of File
 */