/*******************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain
 * this notice you can do whatever you want with this stuff. If we meet some
 * day, and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 *******************************************************************************
 * 
 * File: app_hwcontrol.h
 * 
 * Version: 1.0
 * Created: 16.07.2023
 * 
 * Author: Mario Hellmich <mario.hellmich@web.de>
 * Project: RF Synthesizer MK III
 * 
 * Summary: This header file provides prototypes and definitions for 
 * app_hwcontrol.c.
 * 
 * *****************************************************************************/

#ifndef APP_HWCONTROL_H
#define	APP_HWCONTROL_H


/*Section: Includes ************************************************************/

#include "definitions.h"
#include "app_cmd_parser.h"
#include "app_system_operation.h"
#include "app_spi.h"
#include "util.h"


/*Section: Type definitions and structs ****************************************/

struct mpll_s {
    uint16_t pll_int;
    uint8_t  chdiv_seg1;
    uint8_t  chdiv_seg2;
    uint8_t  chdiv_seg3;
    uint8_t  chdiv_seg_sel;
    uint8_t  drive_lvl;         // RF output drive level, min: 0, max: 63
    bool     outa_mux;
    bool     rfon;
};


typedef union {                                                                 // Convert uint16_t to bytes (the SAM E54 is little-endian)
    uint16_t i16;
    uint8_t byte[2];
} Convert16to8_t;


typedef union {                                                                 // Convert uint32_t to bytes (the SAM E54 is little-endian)
    uint32_t i32;
    uint8_t byte[4];
} Convert32to8_t;


typedef union {                                                                 // Convert uint64_t to bytes (the SAM E54 is little-endian)
    uint64_t i64;
    uint8_t byte[8];
} Convert64to8_t;


#ifdef	__cplusplus
extern "C" {
#endif
 

/*Section: Function prototypes: ************************************************/
    
extern void dds_init(void);
extern void dds_write_tunewd(uint32_t dds_tunewd);
extern void refpll_init(void);
extern void mpll_init(void);
extern void mpll_write(const struct mpll_s *params);
extern void hfilter_write(unsigned int hfiltnumber);
extern void atten_write(unsigned int val);
extern void refpll_write_mult(uint32_t mult);
extern void refpll_set_ext_ref(bool extref);
extern void dac_write(uint16_t val);
extern void bandselect_pllout(bool val);
extern void synthesizer_power_down(bool val);


#ifdef	__cplusplus
}
#endif

#endif	/* APP_HWCONTROL_H */


/*******************************************************************************
 End of File
 */