/*******************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain
 * this notice you can do whatever you want with this stuff. If we meet some
 * day, and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 *******************************************************************************
 * 
 * File: globals.c
 * 
 * Version: 1.0
 * Created: 16.07.2023
 * 
 * Author: Mario Hellmich <mario.hellmich@web.de>
 * Project: RF Synthesizer MK III
 * 
 * Summary: This header file provides global variable definitions for the 
 * signal generator state.
 * 
 * *****************************************************************************/

/*Section: Includes ************************************************************/

#include "app_instr_state.h"


/*Section: Variables ***********************************************************/

volatile Instrument_State_t state;          // Instrument state
volatile Instrument_Error_t error;          // Instrument error
const Version_t fwversion = {1, 0};         // Firmware version
const unsigned int password = 123456;       // Cal protect password

const uint64_t f_pfd        = 100000000;    // Main PLL PFD frequency
const uint64_t f_int_ref    = 10000000;     // Internal reference frequency
const uint64_t f_dds_ref    = 100000000;    // DDS reference frequency
const uint64_t f_dds_sysclk = 400000000;    // DDS system clock


/*Section: Function implementations ********************************************/

/*******************************************************
 * Set instrument state to default.
 *******************************************************/

void set_state_to_default(volatile Instrument_State_t *state, volatile Instrument_Error_t *error)
{
    state->cw_freq        = 1000000000;
    state->start_freq     = FREQ_MIN;
    state->stop_freq      = FREQ_MAX;
    state->dwell          = 10;
    state->npoints        = 201;
    state->refmult        = 10;
    state->level          = -20;
    state->extref         = false;
    state->rfon           = true;
    state->sweep          = false;
    state->single_sweep   = false;
    state->cal            = false;
    state->cal_mode       = CALMODE_NORMAL;
    state->cal_att_stage  = 0;
    error->errstatus      = 0;
}


/*******************************************************************************
 End of File
 */