/*******************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain
 * this notice you can do whatever you want with this stuff. If we meet some
 * day, and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 *******************************************************************************
 * 
 * File: app_spi_comm.h
 * 
 * Version: 1.0
 * Created: 16.07.2023
 * 
 * Author: Mario Hellmich <mario.hellmich@web.de>
 * Project: RF Synthesizer MK III
 * 
 * This header file provides prototypes and definitions for 
 * app_spi.c.
 * 
 * *****************************************************************************/

#ifndef APP_SPI_H
#define	APP_SPI_H

/*Section: Includes ************************************************************/

#include "definitions.h"
#include "rtos_setup.h"
#include "util.h"


/*Section: Type definitions ****************************************************/

typedef enum {
    SPI_ADDR_VOID = 0,
    SPI_ADDR_REFPLL,
    SPI_ADDR_DDS,
    SPI_ADDR_DDSUPDATE,
    SPI_ADDR_MPLL,
    SPI_ADDR_DAC
} SPI_Addr_t;


typedef union {
    uint32_t i32;
    struct {
        char data;
        SPI_Addr_t addr;
    };
} SPI_Queue_Data_t;


/*Section: Variables ***********************************************************/



#ifdef	__cplusplus
extern "C" {
#endif


/*Section: Function prototypes: ************************************************/

extern void APP_SPI_Tasks(void);
    /* This function implements the RTOS task for sending data over the 
     * SPI bus. */
extern void spi_init(void);
extern void spi_send_reg(const uint8_t *buffer, unsigned int len, SPI_Addr_t addr);
extern void clr_chip_select(void);


#ifdef	__cplusplus
}
#endif

#endif	/* APP_SPI_H */


/*******************************************************************************
 End of File
 */