/*******************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain
 * this notice you can do whatever you want with this stuff. If we meet some
 * day, and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 *******************************************************************************
 * 
 * File: app_system_operation.h
 * 
 * Version: 1.0
 * Created: 16.07.2023
 * 
 * Author: Mario Hellmich <mario.hellmich@web.de>
 * Project: RF Synthesizer MK III
 * 
 * Summary: This header file defines function prototypes for 
 * app_system_operation.c, which does high level control of the synthesizer 
 * hardware. 
 * 
 * *****************************************************************************/

#ifndef APP_SYSTEM_OPERATION_H
#define	APP_SYSTEM_OPERATION_H


/*Section: Includes ************************************************************/

#include "definitions.h"
#include "app_instr_state.h"
#include "app_hwcontrol.h"
#include "rtos_setup.h"


#ifdef	__cplusplus
extern "C" {
#endif

/*Section: Type definitions ****************************************************/
    
typedef struct {
    uint32_t freq;
    float lvl;
    bool rf_on;
    bool modified;
} SYS_Output_Setting_t;
    

/*Section: Variables ***********************************************************/

extern const float nominal_lvl_pre_att;
extern const unsigned int att_nstages;


/*Section: Preprocessor directives *********************************************/


/*Section: Function prototypes: ************************************************/

extern void synthesizer_update(void);
extern void ref_update(void);
extern void set_sweep_mode(bool swp_state);
extern bool set_cw_freq_hz(uint64_t freq);
extern bool set_lvl_db(float lvl);
extern bool set_start_frq_hz(uint64_t freq);
extern bool set_stop_frq_hz(uint64_t freq);
extern bool set_dwell_time_ms(float time);
extern bool set_npoints(unsigned int npoints);
extern void set_sweep_single(bool swp_single);
extern void set_extref(bool ref_state);
extern bool set_ref_frq_hz(uint64_t reffreq);
extern float get_lvl_corr_val(uint32_t freq, unsigned int att_step);
extern void set_lvl_corr_val(uint32_t freq, unsigned int att_step, float val);
extern void dump_cal_data(void);
extern void system_reset(void);
extern void selftest(void);
extern void print_errmsg(void);

extern void HW_Initialize(void);
extern void Sweeptimer_Init(void);
extern void SYS_Operation_Tasks(void);


#ifdef	__cplusplus
}
#endif

#endif	/* APP_SYSTEM_OPERATION_H */


/*******************************************************************************
 End of File
 */