/*******************************************************************************
 * "THE BEER-WARE LICENSE" (Revision 42):
 * Mario Hellmich <mario.hellmich@web.de> wrote this file. As long as you retain
 * this notice you can do whatever you want with this stuff. If we meet some
 * day, and you think this stuff is worth it, you can buy me a beer in return.
 * Mario Hellmich
 *******************************************************************************
 * 
 * File: util.c
 * 
 * Version: 1.0
 * Created: 16.07.2023
 * 
 * Author: Mario Hellmich <mario.hellmich@web.de>
 * Project: RF Synthesizer MK III
 * 
 * Summary: This file implements some functions for accessing FIFO buffers.
 * 
 * *****************************************************************************/

/*Section: Includes ************************************************************/

#include "util.h"


/*Section: Definitions**********************************************************/


/*Section: Function implementations ********************************************/

/*******************************************************
 * Basic FIFO buffer operations
 *******************************************************/

int buffer_put(Fifo_Buffer_t *buffer, char byte)
{
    if((buffer->read == buffer->write + 1) || (buffer->read == 0 && (buffer->write + 1 == FIFO_BUFLEN)))        // Buffer full
        return EXIT_FAILURE;
    buffer->buf[buffer->write] = byte;
	(buffer->write)++;
    if( buffer->write >= FIFO_BUFLEN )
        buffer->write = 0;
    return EXIT_SUCCESS;
}


int buffer_get(Fifo_Buffer_t *buffer, char *byte_p)
{
    if(buffer->read == buffer->write)                                                                           // Buffer empty
        return EXIT_FAILURE;
    *byte_p = buffer->buf[buffer->read];
    (buffer->read)++;
    if(buffer->read >= FIFO_BUFLEN)
        buffer->read = 0;
    return EXIT_SUCCESS;
}


/*******************************************************
 * This function realizes a simple blocking delay.
 *******************************************************/

void blocking_delay(unsigned int cycles)
{
    for(int i = 0; i < cycles; i++)
        asm volatile("nop");
}


/*******************************************************
 * Find the index of the lowest and highest significant 
 * bit set in a number.
 *******************************************************/

int ffs(int num)
{
    int order = -1;
    for(int i = 0; i < sizeof(int) * 8; i++)
    {
        if((num >> i) & 1)
        {
            order = i;
            break;
        }
    }
    return order;
}


int fls(int num)
{
    int order = -1;
    for(int i = 0; i < sizeof(int) * 8; i++)
    {
        if((num >> i) & 1)
            order = i;
    }
    return order;
}


/*******************************************************************************
 End of File
 */